searchData={"items":[{"type":"module","title":"GettextTranslator","doc":"A module for translating gettext files.\n\nThis module provides functionality to scan directories for gettext files,\nprocess translation folders, and summarize the results. It leverages helper functions\nand processors defined in other modules.","ref":"GettextTranslator.html"},{"type":"module","title":"Overview - GettextTranslator","doc":"The main entry point of this module is the `translate/2` function which:\n  1. Scans the specified root directory for gettext files using `Parser.scan/1`.\n  2. Processes each folder corresponding to a language.\n  3. Summarizes the total number of translations made.\n\nLanguages that are defined in the `provider`'s `ignored_languages` list will be skipped,\nand a log message is generated.","ref":"GettextTranslator.html#module-overview"},{"type":"module","title":"Example Usage - GettextTranslator","doc":"iex> provider = %{ignored_languages: [\"fr\", \"de\"]}\n    iex> root_path = \"path/to/gettext\"\n    iex> GettextTranslator.translate(provider, root_path)\n    {:ok, total_translations}","ref":"GettextTranslator.html#module-example-usage"},{"type":"function","title":"GettextTranslator.translate/2","doc":"Translates the gettext files located at the given root path.\n\nThis function performs the following steps:\n  1. Scans the `root_gettext_path` for gettext files using `Parser.scan/1`.\n  2. Processes each language folder found by filtering out languages that are ignored\n     (as specified in the `provider` map's `ignored_languages` key) and running the translation\n     process on the rest using `Processor.run/2`.\n  3. Summarizes the total number of translations performed across all folders.","ref":"GettextTranslator.html#translate/2"},{"type":"function","title":"Parameters - GettextTranslator.translate/2","doc":"- `provider`: A map or struct that configures the translation process. It must include an\n    `ignored_languages` key which is a list of language codes to be skipped.\n  - `root_gettext_path`: The root directory path where gettext files are stored.","ref":"GettextTranslator.html#translate/2-parameters"},{"type":"function","title":"Return Value - GettextTranslator.translate/2","doc":"Returns `{:ok, total}` where `total` is the sum of translations performed.\nIf the scan fails, the function will return the corresponding error tuple.","ref":"GettextTranslator.html#translate/2-return-value"},{"type":"function","title":"Examples - GettextTranslator.translate/2","doc":"iex> provider = %{ignored_languages: [\"fr\", \"de\"]}\n    iex> root_gettext_path = \"path/to/gettext\"\n    iex> GettextTranslator.translate(provider, root_gettext_path)\n    {:ok, total_translations}","ref":"GettextTranslator.html#translate/2-examples"},{"type":"module","title":"GettextTranslator.Processor","doc":"Documentation for `GettextTranslator.Processor`.\nHere we process parsing the PO files and extracting the messages.","ref":"GettextTranslator.Processor.html"},{"type":"function","title":"GettextTranslator.Processor.run/2","doc":"","ref":"GettextTranslator.Processor.html#run/2"},{"type":"module","title":"GettextTranslator.Processor.LLM","doc":"LLM processor for the translator behaviour.","ref":"GettextTranslator.Processor.LLM.html"},{"type":"function","title":"GettextTranslator.Processor.LLM.translate/2","doc":"","ref":"GettextTranslator.Processor.LLM.html#translate/2"},{"type":"behaviour","title":"GettextTranslator.Processor.Translator","doc":"Translator behavior.","ref":"GettextTranslator.Processor.Translator.html"},{"type":"type","title":"GettextTranslator.Processor.Translator.endpoint/0","doc":"","ref":"GettextTranslator.Processor.Translator.html#t:endpoint/0"},{"type":"type","title":"GettextTranslator.Processor.Translator.opts/0","doc":"","ref":"GettextTranslator.Processor.Translator.html#t:opts/0"},{"type":"type","title":"GettextTranslator.Processor.Translator.provider/0","doc":"","ref":"GettextTranslator.Processor.Translator.html#t:provider/0"},{"type":"callback","title":"GettextTranslator.Processor.Translator.translate/2","doc":"","ref":"GettextTranslator.Processor.Translator.html#c:translate/2"},{"type":"module","title":"GettextTranslator.Util.Helper","doc":"Helper functions","ref":"GettextTranslator.Util.Helper.html"},{"type":"function","title":"GettextTranslator.Util.Helper.empty_string?/1","doc":"","ref":"GettextTranslator.Util.Helper.html#empty_string?/1"},{"type":"function","title":"GettextTranslator.Util.Helper.lc_messages/0","doc":"","ref":"GettextTranslator.Util.Helper.html#lc_messages/0"},{"type":"module","title":"GettextTranslator.Util.Parser","doc":"Parse files in the gettext root folder","ref":"GettextTranslator.Util.Parser.html"},{"type":"function","title":"GettextTranslator.Util.Parser.parse_provider/0","doc":"","ref":"GettextTranslator.Util.Parser.html#parse_provider/0"},{"type":"function","title":"GettextTranslator.Util.Parser.scan/1","doc":"","ref":"GettextTranslator.Util.Parser.html#scan/1"},{"type":"task","title":"mix gettext_translator.run","doc":"GettextTranslator usage:\n * Base using default gettext folder (priv/gettext)\n    ```\n    mix gettext_translator.run\n    ```\n\n * Providing specific gettext folder\n    ```\n    mix gettext_translator.run my_path/gettext\n    ```","ref":"Mix.Tasks.GettextTranslator.Run.html"},{"type":"extras","title":"GettextTranslator","doc":"# GettextTranslator\n\n[![CI](https://github.com/marmend-company/gettext_translator/actions/workflows/main.yml/badge.svg)](https://github.com/marmend-company/gettext_translator/actions/workflows/main.yml)\n\n**GettextTranslator** is a robust translation utility for Elixir projects that leverages advanced AI endpoints to provide high-quality translations. The library seamlessly integrates with Elixir's Gettext, enabling you to maintain the integrity of your application's messages while translating them accurately. It supports multiple AI providers, making it adaptable to your preferred translation service.\n\n**Changelog:** See [CHANGELOG.md](CHANGELOG.md) for detailed changes in each version.","ref":"readme.html"},{"type":"extras","title":"Features - GettextTranslator","doc":"- **Multi-Provider Support:** Easily switch between translation endpoints such as Ollama AI and OpenAI.\n- **Customizable Configurations:** Define your own translation persona, style, and languages to ignore.\n- **CLI Integration:** Translate Gettext files directly from the command line.\n- **Seamless Gettext Integration:** Automatically translate files in your Gettext directory.","ref":"readme.html#features"},{"type":"extras","title":"Installation - GettextTranslator","doc":"Add `gettext_translator` to your dependencies in your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gettext_translator, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, run:\n\n```sh\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - GettextTranslator","doc":"Configure GettextTranslator in your `config/config.exs` file. Below are examples using two different AI translation endpoints.","ref":"readme.html#configuration"},{"type":"extras","title":"Using Ollama AI - GettextTranslator","doc":"```elixir\nconfig :gettext_translator,\n  endpoint: LangChain.ChatModels.ChatOllamaAI,\n  endpoint_model: \"llama3.2:latest\",\n  endpoint_temperature: 0,\n  endpoint_config: %{}, # Leave empty if running Ollama locally with the default API endpoint\n  persona: \"You are a professional translator. Your goal is to translate the message to the target language while preserving meaning and length.\",\n  style: \"Casual, using simple language\",\n  ignored_languages: [\"en\"]\n```","ref":"readme.html#using-ollama-ai"},{"type":"extras","title":"Using OpenAI - GettextTranslator","doc":"```elixir\nconfig :gettext_translator,\n  endpoint: LangChain.ChatModels.ChatOpenAI,\n  endpoint_model: \"gpt-4\",\n  endpoint_temperature: 0,\n  endpoint_config: %{\n    \"openai_key\" => \"YOUR_OPENAI_KEY\",\n    \"openai_org_id\" => \"YOUR_ORG_ID\"\n  },\n  persona: \"You are a professional translator. Your goal is to translate the message to the target language while preserving meaning and length.\",\n  style: \"Casual, using simple language\",\n  ignored_languages: [\"en\"]\n```","ref":"readme.html#using-openai"},{"type":"extras","title":"Usage - GettextTranslator","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Running the Translator - GettextTranslator","doc":"#### Translate Using the Default Gettext Folder\nTo translate the default Gettext folder (`priv/gettext`), simply run:\n\n```sh\nmix gettext_translator.run\n```\n\n#### Translate Using a Specific Gettext Folder\nIf your Gettext files are located in a different directory, specify the path:\n\n```sh\nmix gettext_translator.run path/to/your/gettext\n```","ref":"readme.html#running-the-translator"},{"type":"extras","title":"Advanced Examples - GettextTranslator","doc":"#### Batch Translation Script\nFor projects with multiple Gettext directories, you can create a custom Elixir module to run translations in batch:\n\n```elixir\ndefmodule BatchTranslator do\n  def run do\n    [\"priv/gettext\", \"lib/my_app/gettext\"]\n    |> Enum.each(fn path ->\n      System.cmd(\"mix\", [\"gettext_translator.run\", path])\n    end)\n  end\nend\n```\n\nRun the batch translation in IEx:\n\n```sh\niex -S mix\niex> BatchTranslator.run()\n```\n\n#### Overriding Configurations at Runtime\nYou might want to adjust the translation behavior without changing your config files permanently. Override settings in IEx:\n\n```elixir\niex> Application.put_env(:gettext_translator, :persona, \"Translate concisely and accurately.\")\n```","ref":"readme.html#advanced-examples"},{"type":"extras","title":"Documentation - GettextTranslator","doc":"Comprehensive documentation is available on [HexDocs](https://hexdocs.pm/gettext_translator). It covers detailed configuration options, advanced usage, integration guides, and best practices.","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - GettextTranslator","doc":"We welcome contributions from the community! Please review our [CONTRIBUTING.md](CONTRIBUTING.md) for guidelines on submitting issues and pull requests.","ref":"readme.html#contributing"},{"type":"extras","title":"License - GettextTranslator","doc":"GettextTranslator is released under the Apache License 2.0 License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Work in progress features and enhancements.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- LLM integration for gettext files.\n\n## [0.1.0] - 2025-02-23","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of GettextTranslator.\n- Multi-provider support for AI translation.\n- CLI integration for translating Gettext files.\n- Basic documentation and configuration examples.","ref":"changelog.html#added"},{"type":"extras","title":"Contributing to GettextTranslator","doc":"# Contributing to GettextTranslator\n\nThank you for considering contributing to Gettext Translator! We welcome improvements, bug reports, and feature suggestions from the community.","ref":"contributing.html"},{"type":"extras","title":"How to Contribute - Contributing to GettextTranslator","doc":"","ref":"contributing.html#how-to-contribute"},{"type":"extras","title":"Reporting Bugs - Contributing to GettextTranslator","doc":"- Please use the [Issues](https://github.com/marmend-company/gettext_translator/issues) section to report any bugs.\n- Include detailed information such as steps to reproduce, expected vs. actual behavior, and screenshots if applicable.","ref":"contributing.html#reporting-bugs"},{"type":"extras","title":"Suggesting Enhancements - Contributing to GettextTranslator","doc":"- Use the [Issues](https://github.com/marmend-company/gettext_translator/issues) section to propose new features or improvements.\n- Discuss your ideas with the community to gather feedback before implementation.","ref":"contributing.html#suggesting-enhancements"},{"type":"extras","title":"Pull Request Process - Contributing to GettextTranslator","doc":"1. **Fork** the repository.\n2. **Create a new branch** with a descriptive name for your changes.\n3. **Implement your changes** and ensure that you add tests if applicable.\n4. **Run the test suite** to confirm all tests pass.\n5. **Submit a pull request** to the `main` branch with a clear description of your changes.","ref":"contributing.html#pull-request-process"},{"type":"extras","title":"Code of Conduct - Contributing to GettextTranslator","doc":"By contributing, you agree to abide by our [Code of Conduct](CODE_OF_CONDUCT.md). Please review it before making any contributions.","ref":"contributing.html#code-of-conduct"},{"type":"extras","title":"Questions? - Contributing to GettextTranslator","doc":"If you have any questions or need further assistance, please feel free to open an issue or join the discussion on [GitHub Discussions](https://github.com/marmend-company/gettext_translator/discussions).\n\nHappy coding!","ref":"contributing.html#questions"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}